@@ -3,6 +3,10 @@ from dask_jobqueue import LSFCluster
 import dask.config
 from pathlib import Path
 import os
+import sys
+import time
+
+SCALE_DELAY = 30
 
 
 class _cluster(object):
@@ -15,10 +19,10 @@ class _cluster(object):
         return self
 
     def __exit__(self, type, value, traceback):
-        if self.cluster is not None:
-            self.scale_cluster(0)
         if self.client is not None:
             self.client.close()
+        if self.cluster is not None:
+            self.cluster.close()
 
     def set_cluster(self, cluster):
         self.cluster = cluster
@@ -27,6 +31,10 @@ class _cluster(object):
 
     def scale_cluster(self, nworkers):
         self.cluster.scale(jobs=nworkers)
+        # wait a little whlie for workers
+        print(f"Waiting {SCALE_DELAY} seconds for cluster to scale")
+        time.sleep(SCALE_DELAY)
+        print("Cluster wait time complete")
 
     def modify_dask_config(self, options):
         dask.config.set(options)
@@ -50,6 +58,7 @@ class janelia_lsf_cluster(_cluster):
         # set environment variables for maximum multithreading
         tpw = 2*cores  # threads per worker
         env_extra = [
+            f"export MKL_NUM_THREADS={tpw}",
             f"export NUM_MKL_THREADS={tpw}",
             f"export OPENBLAS_NUM_THREADS={tpw}",
             f"export OPENMP_NUM_THREADS={tpw}",
@@ -70,7 +79,7 @@ class janelia_lsf_cluster(_cluster):
         # set all core/memory related variables
         memory = str(15*cores)+'GB'
         ncpus = cores
-        mem = 15000*cores
+        mem = int(15e9*cores)
 
         # create cluster
         cluster = LSFCluster(
@@ -87,6 +96,8 @@ class janelia_lsf_cluster(_cluster):
         client = Client(cluster)
         self.set_cluster(cluster)
         self.set_client(client)
+        print("Cluster dashboard link: ", cluster.dashboard_link)
+        sys.stdout.flush()
 
 
 class local_cluster(_cluster):
